@@ -3,5 +3,5 @@ from PyOfficeRobot.api import file
 
 print('=' * 30)
 print('本开源项目的源码仓库：https://github.com/CoderWanFeng/PyOfficeRobot')
-print('请+【项目交流群】：http://t.cn/A6SSrID0')
+print('请+【项目交流群】：http://www.python4office.cn/wechat-group/')
 print('=' * 30)
